package cn.com.qmth.examcloud.service.core.api;

import io.swagger.annotations.ApiOperation;

import java.io.IOException;
import java.util.Date;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import cn.com.qmth.examcloud.common.util.excel.ExcelError;
import cn.com.qmth.examcloud.service.core.entity.Course;
import cn.com.qmth.examcloud.service.core.repo.CourseRepo;
import cn.com.qmth.examcloud.service.core.service.CourseService;

/**
 * 课程服务API
 * Created by songyue on 17/1/14.
 */
@RestController
@RequestMapping("${app.api.root}/course")
public class CourseApi {

    @Autowired
    CourseRepo courseRepo;

    @Autowired
    CourseService courseService;

    @ApiOperation(value="查询所有课程",notes="enable为查询条件，可为空")
    @GetMapping
    public ResponseEntity getAllCourse(@RequestParam Long orgId,@RequestParam(required = false) Boolean enable){
    	List<Course> list = null;
    	if(enable!=null){
    		list = courseRepo.findByOrgIdAndEnable(orgId,enable);
    	}else{
    		list = courseRepo.findByOrgId(orgId);
    	}
    	return new ResponseEntity(list, HttpStatus.OK);
    }

    @ApiOperation(value="按ID查询课程",notes="ID查询")
    @GetMapping("/{id}")
    public ResponseEntity getCourseById(@PathVariable Long id){
        return new ResponseEntity(courseRepo.findOne(id),HttpStatus.OK);
    }

    @ApiOperation(value="新增课程",notes="新增")
    @PostMapping
    public ResponseEntity addCourse(@RequestBody Course course){
        return new ResponseEntity(courseRepo.save(course),HttpStatus.CREATED);
    }

    @ApiOperation(value="更新课程",notes="更新")
    @PutMapping
    public ResponseEntity updateCourse(@RequestBody Course course){
    	course.setUpdateTime(new Date());
        return new ResponseEntity(courseRepo.save(course),HttpStatus.OK);
    }

    @ApiOperation(value="按ID删除课程",notes="删除")
    @DeleteMapping("/{id}")
    public ResponseEntity deleteCourse(@PathVariable Long id){
        courseRepo.delete(id);
        return new ResponseEntity(HttpStatus.OK);
    }
    
    @ApiOperation(value="导入课程",notes = "导入")
    @PostMapping("/import")
    public ResponseEntity importCourse(@RequestParam Long orgId,@RequestParam MultipartFile file){
    	try {
    		List<ExcelError> errors = courseService.importCourse(orgId,file.getInputStream());
    		return new ResponseEntity(errors,HttpStatus.OK);
		} catch (IOException e) {
			e.printStackTrace();
			return new ResponseEntity(HttpStatus.INTERNAL_SERVER_ERROR);
		}
    }
}
