package cn.com.qmth.examcloud.service.core.service;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Example;
import org.springframework.data.domain.ExampleMatcher;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;

import cn.com.qmth.examcloud.common.util.ErrorMsg;
import cn.com.qmth.examcloud.service.core.entity.Student;
import cn.com.qmth.examcloud.service.core.repo.StudentRepo;

/**
 * 学生服务类
 * Created by songyue on 17/1/14.
 */
@Service
public class StudentService {
	
    @Autowired
    StudentRepo studentRepo;
    
    private static final String JPG = ".jpg";

    /**
     * 获取所有学生(分页)
     * @param studentCriteria
     * @param pageable
     * @return
     */
    public Page<Student> getAllStudent(Student studentCriteria, Pageable pageable){
        ExampleMatcher exampleMatcher = ExampleMatcher.matching();
        Example<Student> studentExample = Example.of(studentCriteria, exampleMatcher);
        return studentRepo.findAll(studentExample,pageable);
    }

    /**
     * 获取所有学生
     * @param studentCriteria
     * @return
     */
    public List<Student> getAllStudent(Student studentCriteria){
        ExampleMatcher exampleMatcher = ExampleMatcher.matching();
        Example<Student> studentExample = Example.of(studentCriteria, exampleMatcher);
        return studentRepo.findAll(studentExample);
    }

    /**
     * 绑定学生照片
     * @return
     */
	public List<ErrorMsg> photopBundled(Long rootOrgId, File directory) {
		List<ErrorMsg> list = new ArrayList<ErrorMsg>();
		if(directory.isDirectory()){
			for (File file : directory.listFiles()) {
				if(!file.getName().endsWith(JPG)){
					list.add(new ErrorMsg(file.getName()+"格式错误，文件名格式必须是jpg(小写)"));
				}
				String fileName = file.getName().split(JPG)[0];
				//先查学号
				Student student = studentRepo.findByUserRootOrgIdAndStudentCode(rootOrgId,fileName);
				if(student == null){//学号不存在查身份证号
					student = studentRepo.findByIdentityNumber(fileName);
				}
				if(student!=null ){//学生存在则绑定照片
					student.setPhotoPath(student.getUser().getRootOrgId()+File.separator+"photo"+ File.separator+fileName);
					studentRepo.save(student);
				}
			}
		}else{
			list.add(new ErrorMsg("文件路径不正确"));
		}
		return list;
	}

}
